@@ -56,7 +56,9 @@ typedef WINAPI HRESULT(*SHGETFOLDERPATHPROC) (HWND hwndOwner,
                                               HANDLE hToken,
                                               DWORD dwFlags, LPTSTR pszPath);
 #endif
+
 #include "winmonitors.h"
+#include "nonsdk_extinit.h"
 #include "pseudoramiX/pseudoramiX.h"
 
 #include "glx_extinit.h"
@@ -69,8 +71,6 @@ typedef WINAPI HRESULT(*SHGETFOLDERPATHPROC) (HWND hwndOwner,
  * References to external symbols
  */
 
-extern Bool noRRXineramaExtension;
-
 /*
  * Function prototypes
  */
@@ -775,7 +775,6 @@ winUseMsg(void)
     ErrorF("-engine engine_type_id\n"
            "\tOverride the server's automatically selected engine type:\n"
            "\t\t1 - Shadow GDI\n"
-           "\t\t2 - Shadow DirectDraw - obsolete\n"
            "\t\t4 - Shadow DirectDraw4 Non-Locking\n"
         );
 
@@ -786,10 +785,6 @@ winUseMsg(void)
 
     ErrorF("-ignoreinput\n" "\tIgnore keyboard and mouse input.\n");
 
-#ifdef XWIN_MULTIWINDOWEXTWM
-    ErrorF("-internalwm\n" "\tRun the internal window manager.\n");
-#endif
-
 #ifdef XWIN_XF86CONFIG
     ErrorF("-keyboard\n"
            "\tSpecify a keyboard device from the configuration file.\n");
@@ -823,11 +818,6 @@ winUseMsg(void)
     ErrorF("-multiwindow\n" "\tRun the server in multi-window mode.\n");
 #endif
 
-#ifdef XWIN_MULTIWINDOWEXTWM
-    ErrorF("-mwextwm\n"
-           "\tRun the server in multi-window external window manager mode.\n");
-#endif
-
     ErrorF("-nodecoration\n"
            "\tDo not draw a window border, title bar, etc.  Windowed\n"
            "\tmode only.\n");
@@ -1000,8 +990,6 @@ InitOutput(ScreenInfo * pScreenInfo, int argc, char *argv[])
     {
       int pass;
 
-      noRRXineramaExtension = TRUE;
-
       PseudoramiXExtensionInit();
 
       /* Add primary monitor on pass 0, other monitors on pass 1, to ensure
